"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateReceiptIos = exports.presentCodeRedemptionSheetIOS = exports.getReceiptIOS = exports.getPromotedProductIOS = exports.getPendingPurchasesIOS = exports.deepLinkToSubscriptionsIos = exports.clearTransactionIOS = exports.clearProductsIOS = exports.buyPromotedProductIOS = void 0;

var _reactNative = require("react-native");

var _internal = require("../internal");

const {
  RNIapIos
} = _reactNative.NativeModules;

/**
 * Get the current receipt base64 encoded in IOS.
 * @param {forceRefresh?:boolean}
 * @returns {Promise<ProductPurchase[]>}
 */
const getPendingPurchasesIOS = async () => (0, _internal.getIosModule)().getPendingTransactions();
/**
 * Get the current receipt base64 encoded in IOS.
 * From: https://apphud.com/blog/app-store-receipt-validation#what-is-app-store-receipt
 > Does a receipt always exist in the app?
 > If a user downloaded the app from the App Store – yes. However, in sandbox if your app was installed via Xcode or Testflight, then there won't be a receipt until you make a purchase or restore.
 * 
 ## Usage 
 ```tsx
import {useCallback} from 'react';
import {getReceiptIOS} from 'react-native-iap';

const receipt = useCallback(async () => await getReceiptIOS({forceRefresh: false}));
```
 * @param {forceRefresh?:boolean} Requests the receipt from Bundle.main.appStoreReceiptURL. Based on the note above, looks like forceRefresh only makes sense when testing an app not downloaded from the Appstore.
 * @returns {Promise<string>} The receipt data
 */


exports.getPendingPurchasesIOS = getPendingPurchasesIOS;

const getReceiptIOS = async _ref => {
  let {
    forceRefresh
  } = _ref;

  if (!(0, _internal.isIosStorekit2)()) {
    return RNIapIos.requestReceipt(forceRefresh ?? false);
  } else {
    return Promise.reject('Only available on Sk1');
  }
};
/**
 * Launches a modal to register the redeem offer code in IOS.
 * @returns {Promise<null>}
 */


exports.getReceiptIOS = getReceiptIOS;

const presentCodeRedemptionSheetIOS = async () => (0, _internal.getIosModule)().presentCodeRedemptionSheet();
/**
 * Should Add Store Payment (iOS only)
 *   Indicates the the App Store purchase should continue from the app instead of the App Store.
 * @returns {Promise<Product | null>} promoted product
 */


exports.presentCodeRedemptionSheetIOS = presentCodeRedemptionSheetIOS;

const getPromotedProductIOS = () => {
  if (!(0, _internal.isIosStorekit2)()) {
    return RNIapIos.promotedProduct();
  } else {
    return Promise.reject('Only available on Sk1');
  }
};
/**
 * Buy the currently selected promoted product (iOS only)
 *   Initiates the payment process for a promoted product. Should only be called in response to the `iap-promoted-product` event.
 * @returns {Promise<void>}
 */


exports.getPromotedProductIOS = getPromotedProductIOS;

const buyPromotedProductIOS = () => (0, _internal.getIosModule)().buyPromotedProduct();

exports.buyPromotedProductIOS = buyPromotedProductIOS;

const fetchJsonOrThrow = async (url, receiptBody) => {
  const response = await fetch(url, {
    method: 'POST',
    headers: {
      Accept: 'application/json',
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(receiptBody)
  });

  if (!response.ok) {
    throw Object.assign(new Error(response.statusText), {
      statusCode: response.status
    });
  }

  return response.json();
};

const TEST_RECEIPT = 21007;

const requestAgnosticReceiptValidationIos = async receiptBody => {
  const response = await fetchJsonOrThrow('https://buy.itunes.apple.com/verifyReceipt', receiptBody); // Best practice is to check for test receipt and check sandbox instead
  // https://developer.apple.com/documentation/appstorereceipts/verifyreceipt

  if (response && response.status === TEST_RECEIPT) {
    const testResponse = await fetchJsonOrThrow('https://sandbox.itunes.apple.com/verifyReceipt', receiptBody);
    return testResponse;
  }

  return response;
};
/**
 * Validate receipt for iOS.
 * @param {object} receiptBody the receipt body to send to apple server.
 * @param {boolean} isTest whether this is in test environment which is sandbox.
 * @returns {Promise<Apple.ReceiptValidationResponse | false>}
 */


const validateReceiptIos = async _ref2 => {
  let {
    receiptBody,
    isTest
  } = _ref2;

  if (isTest == null) {
    return await requestAgnosticReceiptValidationIos(receiptBody);
  }

  const url = isTest ? 'https://sandbox.itunes.apple.com/verifyReceipt' : 'https://buy.itunes.apple.com/verifyReceipt';
  const response = await fetchJsonOrThrow(url, receiptBody);
  return response;
};
/**
 * Clear Transaction (iOS only)
 *   Finish remaining transactions. Related to issue #257 and #801
 *     link : https://github.com/dooboolab/react-native-iap/issues/257
 *            https://github.com/dooboolab/react-native-iap/issues/801
 * @returns {Promise<void>}
 */


exports.validateReceiptIos = validateReceiptIos;

const clearTransactionIOS = () => (0, _internal.getIosModule)().clearTransaction();
/**
 * Clear valid Products (iOS only)
 *   Remove all products which are validated by Apple server.
 * @returns {void}
 */


exports.clearTransactionIOS = clearTransactionIOS;

const clearProductsIOS = () => (0, _internal.getIosModule)().clearProducts();

exports.clearProductsIOS = clearProductsIOS;

const deepLinkToSubscriptionsIos = () => _reactNative.Linking.openURL('https://apps.apple.com/account/subscriptions');

exports.deepLinkToSubscriptionsIos = deepLinkToSubscriptionsIos;
//# sourceMappingURL=ios.js.map